import React from 'react';
import ReactDOM from 'react-dom';
import { Container, Row, Col, Form, Navbar, Button, Nav, NavItem, FormGroup, FormLabel } from 'react-bootstrap';
import DatePicker from '../src/index.jsx';
import createReactClass from 'create-react-class';

const spanishDayLabels = ['Dom', 'Lu', 'Ma', 'Mx', 'Ju', 'Vi', 'Sab'];
const spanishMonthLabels = ['Enero', 'Febrero', 'Marzo', 'Abril', 'Mayo', 'Junio', 'Julio', 'Agosto', 'Septiembre', 'Octubre', 'Noviembre', 'Diciembre'];
const wapperDivStyle = { border: '1px solid #ccc' };
const scrollingDivStyle = { padding: '10px', height: '70px', overflow: 'auto' };

const App = createReactClass({
  getInitialState() {
    return {
      date: new Date().toISOString(),
      previousDate: null,
      minDate: null,
      maxDate: null,
      focused: false,
      invalid: false
    };
  },
  handleChange(value) {
    this.setState({
      date: value
    });
  },
  handleMinChange(value) {
    this.setState({
      minDate: value
    });
  },
  handleMaxChange(value) {
    this.setState({
      maxDate: value
    });
  },
  handlePlacement() {
    return 'top';
  },
  handleRandomPlacement() {
    const placementKey = Math.floor((Math.random()*4) + 1);
    switch (placementKey) {
      case 1:
        return 'top';
      case 2:
        return 'left';
      case 4:
        return 'right';
      default:
        return 'bottom';
    }
  },
  handleValidationCheck(e) {
    e.preventDefault();
    this.setState(() => ({
      invalid: false
    }));
  },
  handleInvalidDate(e) {
    e.preventDefault();
    this.setState(() => ({
      invalid: true
    }));
  },
  handleResetValidation(e) {
    e.preventDefault();
    this.setState(() => ({
      invalid: false
    }));
  },
  render() {
    const LabelISOString = new Date().toISOString();
    return <Container>
      <Row>
        <Col xs={12}>
          <h1>React-Bootstrap Date Picker</h1>
        </Col>
      </Row>
      <Row>
        <Col xs={12}>
          <Navbar>
            <Nav variant="pills">
              <NavItem href="https://github.com/pushtell/react-bootstrap-date-picker/blob/master/example/app.jsx">Example Source</NavItem>
              <NavItem href="https://github.com/pushtell/react-bootstrap-date-picker">Documentation on Github</NavItem>
              <NavItem href="https://www.npmjs.com/package/react-bootstrap-date-picker">NPM Package</NavItem>
            </Nav>
          </Navbar>
        </Col>
      </Row>
      <Row>
        <Col xs={6}>
          <h2>Change Handler</h2>
        </Col>
        <Col xs={6}>
          <h2>Disabled</h2>
        </Col>
      </Row>
      <Row>
        <Col sm={6}>
          <FormGroup controlId="change_handler">
            <FormLabel>Change Handler</FormLabel>
            <DatePicker onChange={this.handleChange} placeholder="Placeholder" value={this.state.date} id="change_handler_example" />
            <div>Help</div>
          </FormGroup>
        </Col>
        <Col sm={6}>
          <FormGroup controlId="disabled">
            <FormLabel>Disabled</FormLabel>
            <DatePicker disabled={true} onChange={this.handleChange} placeholder="Placeholder" value={this.state.date} id="disabled_example" />
            <div>Help</div>
          </FormGroup>
        </Col>
      </Row>
      <Row>
        <Col sm={6}>
          <FormGroup controlId="required">
            <FormLabel>Required</FormLabel>
            <DatePicker required onChange={this.handleChange} placeholder="Placeholder" value={this.state.date} id="required_example" />
            <div>Help</div>
          </FormGroup>
        </Col>
      </Row>
      <Row>
        <Col xs={6}>
          <h2>Blur and Focus Events</h2>
        </Col>
        <Col xs={6}>
          <h2>Week Starts on Monday</h2>
        </Col>
      </Row>
      <Row>
        <Col sm={6}>
          <FormGroup>
            <FormLabel>{this.state.focused ? 'Focused' : 'Blurred'}</FormLabel>
            <DatePicker onChange={this.handleChange} placeholder="Placeholder" value={this.state.date} onFocus={() => {this.setState({focused: true});}} onBlur={() => {this.setState({focused: false});}} />
            <div>This is {this.state.focused ? 'focused' : 'blurred'}.</div>
          </FormGroup>
        </Col>
        <Col sm={6}>
          <FormGroup>
            <FormLabel>Week Starts on Monday</FormLabel>
            <DatePicker onChange={this.handleChange} weekStartsOn={1} placeholder="Placeholder" value={this.state.date} />
            <div>Help</div>
          </FormGroup>
        </Col>
      </Row>
      <Row>
        <Col xs={12}>
          <h2>Styles</h2>
        </Col>
      </Row>
      <Row>
        <Col sm={4}>
          <FormGroup>
            <FormLabel>Success</FormLabel>
            <DatePicker placeholder="Placeholder" />
            <div>Help</div>
          </FormGroup>
        </Col>
        <Col sm={4}>
          <FormGroup>
            <FormLabel>Warning</FormLabel>
            <DatePicker placeholder="Placeholder" />
            <div>Help</div>
          </FormGroup>
        </Col>
        <Col sm={4}>
          <FormGroup>
            <FormLabel>Error</FormLabel>
            <DatePicker placeholder="Placeholder" />
            <div>Help</div>
          </FormGroup>
        </Col>
      </Row>
      <Row>
        <Col xs={12}>
          <h2>Date Format</h2>
        </Col>
      </Row>
      <Row>
        <Col sm={4}>
          <FormGroup>
            <FormLabel>MM/DD/YYYY</FormLabel>
            <DatePicker dateFormat="MM/DD/YYYY" onChange={this.handleChange} value={this.state.date} />
            <div>Help</div>
          </FormGroup>
        </Col>
        <Col sm={4}>
          <FormGroup>
            <FormLabel>DD-MM-YYYY</FormLabel>
            <DatePicker dateFormat="DD-MM-YYYY" onChange={this.handleChange} value={this.state.date} />
            <div>Help</div>
          </FormGroup>
        </Col>
        <Col sm={4}>
          <FormGroup>
            <FormLabel>YYYY/MM/DD</FormLabel>
            <DatePicker dateFormat="YYYY/MM/DD" onChange={this.handleChange} value={this.state.date} />
            <div>Help</div>
          </FormGroup>
        </Col>
      </Row>
      <Row>
        <Col xs={12}>
          <h2>Min/Max Dates</h2>
        </Col>
      </Row>
      <Row>
        <Col sm={6}>
          <FormGroup>
            <FormLabel>Example Min/Max</FormLabel>
            <DatePicker minDate={this.state.minDate} maxDate={this.state.maxDate} onChange={this.handleChange} value={this.state.date} />
            <div>Sample min/max DatePicker using configured values</div>
          </FormGroup>
        </Col>
        <Col sm={3}>
          <FormGroup>
            <FormLabel>Min</FormLabel>
            <DatePicker onChange={this.handleMinChange} value={this.state.minDate} />
            <div>{'Configure Example minDate'}</div>
            <div>{`value: ${this.state.minDate}`}</div>
          </FormGroup>
        </Col>
        <Col sm={3}>
          <FormGroup>
            <FormLabel>Max</FormLabel>
            <DatePicker onChange={this.handleMaxChange} value={this.state.maxDate} />
            <div>{'Configure Example maxDate'}</div>
            <div>{`value: ${this.state.maxDate}`}</div>
          </FormGroup>
        </Col>
      </Row>
      <Row>
        <Col xs={6}>
          <h2>Show Week Numbers</h2>
        </Col>
      </Row>
      <Row>
        <Col xs={6}>
          <FormGroup controlId="show_weeks">
            <FormLabel>Show Weeks</FormLabel>
            <DatePicker onChange={this.handleChange} placeholder="Placeholder" value={this.state.date} id="show_dates_example" showWeeks={true} />
            <div>Help</div>
          </FormGroup>
        </Col>
      </Row>
      <Row>
        <Col xs={6}>
          <h2>Validation</h2>
        </Col>
      </Row>
      <Row>
        <Form onSubmit={this.handleValidationCheck}>
          <Col xs={6}>
              <FormGroup controlId="custom_validation_example_default">
                <FormLabel>Default</FormLabel>
                <DatePicker
                  onChange={this.handleChange}
                  placeholder="Placeholder"
                  required
                />
            </FormGroup>
          </Col>
          <Col xs={6}>
              <FormGroup controlId="custom_validation_example_oninvalid">
                <FormLabel>onInvalid override</FormLabel>
                <DatePicker
                  onChange={this.handleChange}
                  placeholder="Placeholder"
                  onInvalid={this.handleInvalidDate}
                  required
                />
                {this.state.invalid
                  && <div>You must pick a date.</div>}
            </FormGroup>
          </Col>
          <Col xs={6}>
            <Button type="submit">Validate</Button>
            <Button type="button" onClick={this.handleResetValidation}>Reset</Button>
          </Col>
        </Form>
      </Row>
      <Row>
        <Col xs={12}>
          <h2>Custom</h2>
        </Col>
      </Row>
      <Row>
        <Col sm={4}>
          <FormGroup>
            <FormLabel>Previous / Next Buttons</FormLabel>
            <DatePicker placeholder="Placeholder" />
            <div>Help</div>
          </FormGroup>
        </Col>
        <Col sm={4}>
          <FormGroup>
            <FormLabel>Padding</FormLabel>
            <DatePicker placeholder="Placeholder" cellPadding="10px" />
            <div>Help</div>
          </FormGroup>
        </Col>
        <Col sm={4}>
          <FormGroup>
            <FormLabel>Day and Month Labels</FormLabel>
            <DatePicker placeholder="Placeholder" dayLabels={spanishDayLabels} monthLabels={spanishMonthLabels} />
            <div>Help</div>
          </FormGroup>
        </Col>
      </Row>
      <Row>
        <Col sm={6}>
          <FormGroup>
            <FormLabel>Clear Button</FormLabel>
            <DatePicker placeholder="Placeholder" />
            <div>Help</div>
          </FormGroup>
        </Col>
        <Col sm={6}>
          <FormGroup controlId="no_clear_button">
            <FormLabel>No Clear Button</FormLabel>
            <DatePicker placeholder="Placeholder" showClearButton={false} />
            <div>Help</div>
          </FormGroup>
        </Col>
      </Row>
      <Row>
        <Col sm={6}>
          <FormGroup>
            <FormLabel>FormControl Style</FormLabel>
            <DatePicker style={{width:'100%', backgroundColor:'#FFEEEE'}} />
            <div>&#123;width:"100%", backgroundColor:"#FFEEEE"&#125;</div>
          </FormGroup>
        </Col>
        <Col sm={6}>
          <FormGroup>
            <FormLabel>Today Button</FormLabel>
            <DatePicker showTodayButton />
          </FormGroup>
        </Col>
      </Row>
      <Row>
        <Col sm={6}>
          <FormGroup>
            <FormLabel>Thursday First Day of Week</FormLabel>
            <DatePicker weekStartsOn={4} />
          </FormGroup>
        </Col>
        <Col sm={6}>
          <FormGroup>
            <FormLabel>Control Element</FormLabel>
            <DatePicker customControl={<CustomControl />} />
          </FormGroup>
        </Col>
      </Row>
      <Row>
        <Col xs={12}>
          <h2>Placement</h2>
        </Col>
      </Row>
      <Row>
        <Col sm={3}>
          <FormGroup>
            <FormLabel>Top</FormLabel>
            <DatePicker placeholder="Placeholder" calendarPlacement="top" />
            <div>Help</div>
          </FormGroup>
        </Col>
        <Col sm={3}>
          <FormGroup>
            <FormLabel>Right</FormLabel>
            <DatePicker placeholder="Placeholder" calendarPlacement="right" />
            <div>Help</div>
          </FormGroup>
        </Col>
        <Col sm={3}>
          <FormGroup>
            <FormLabel>Bottom</FormLabel>
            <DatePicker placeholder="Placeholder" calendarPlacement="bottom" />
            <div>Help</div>
          </FormGroup>
        </Col>
        <Col sm={3}>
          <FormGroup>
            <FormLabel>Left</FormLabel>
            <DatePicker placeholder="Placeholder" calendarPlacement="left" />
            <div>Help</div>
          </FormGroup>
        </Col>
      </Row>
      <Row>
        <Col sm={6}>
          <FormGroup>
            <FormLabel>Placement determined by function</FormLabel>
            <DatePicker placeholder="Placeholder" calendarPlacement={this.handlePlacement} />
            <div>Placed at top</div>
          </FormGroup>
        </Col>
        <Col sm={6}>
          <FormGroup>
            <FormLabel>Random placement</FormLabel>
            <DatePicker placeholder="Placeholder" calendarPlacement={this.handleRandomPlacement} />
            <div>Placement is random in either of the four directions</div>
          </FormGroup>
        </Col>
      </Row>
      <Row>
        <Col xs={12}>
          <h2>Placed in a Scrolling Container</h2>
        </Col>
      </Row>
      <Row>
        <Col sm={6}>
          <h4>Popover in scroll region</h4>
          <div style={wapperDivStyle}>
            <div style={scrollingDivStyle}>
                <DatePicker placeholder="Start Date" /><br/>
                <DatePicker placeholder="End Date" />
            </div>
          </div>
        </Col>
        <Col sm={6}>
          <h4>Popover outside scroll region</h4>
          <div style={wapperDivStyle}>
            <div style={scrollingDivStyle}>
                <DatePicker placeholder="Start Date" calendarContainer={document.body} /><br/>
                <DatePicker placeholder="End Date"  calendarContainer={document.body} />
            </div>
          </div>
        </Col>
      </Row>
      <Row>
        <Col xs={12}>
          <h2>Sizes</h2>
        </Col>
      </Row>
      <Row>
        <Col sm={6}>
          <FormGroup>
            <FormLabel>Label</FormLabel>
            <DatePicker placeholder="Placeholder" />
            <div>Help</div>
          </FormGroup>
        </Col>
        <Col sm={6}>
          <FormGroup size="sm">
            <FormLabel>Label</FormLabel>
            <DatePicker placeholder="Placeholder" value={this.state.date} />
            <div>Help</div>
          </FormGroup>
        </Col>
      </Row>
      <Row>
        <Col sm={6}>
          <FormGroup>
            <FormLabel>Label</FormLabel>
            <DatePicker placeholder="Placeholder" />
            <div>Help</div>
          </FormGroup>
        </Col>
        <Col sm={6}>
          <FormGroup>
            <FormLabel>Label</FormLabel>
            <DatePicker placeholder="Placeholder" value={this.state.date} />
            <div>Help</div>
          </FormGroup>
        </Col>
      </Row>
      <Row>
        <Col sm={6}>
          <FormGroup size="lg">
            <FormLabel>Label</FormLabel>
            <DatePicker placeholder="Placeholder" />
            <div>Help</div>
          </FormGroup>
        </Col>
        <Col sm={6}>
          <FormGroup size="lg">
            <FormLabel>Label</FormLabel>
            <DatePicker placeholder="Placeholder" value={this.state.date} />
            <div>Help</div>
          </FormGroup>
        </Col>
      </Row>
    </Container>;
  }
});

const CustomControl = createReactClass({
  displayName: 'CustomControl',

  render() {
    const {
      value,
      placeholder,
      ...rest,
    } = this.props;

    return <Button {...rest}>{value || placeholder}</Button>;
  },
});

ReactDOM.render(<App />, document.getElementById('react'));
